@@ -14,14 +14,6 @@ function _aws_cdk_aws_codecommit_CodeConfig(p) {
         _aws_cdk_aws_codecommit_CfnRepository_CodeProperty(p.code);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_codecommit_RepositoryTriggerOptions(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    if (!visitedObjects.has(p.events))
-        _aws_cdk_aws_codecommit_RepositoryEventTrigger(p.events);
-    visitedObjects.delete(p);
-}
 function _aws_cdk_aws_codecommit_RepositoryProps(p) {
     if (p == null)
         return;
@@ -30,6 +22,14 @@ function _aws_cdk_aws_codecommit_RepositoryProps(p) {
         _aws_cdk_aws_codecommit_Code(p.code);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_codecommit_RepositoryTriggerOptions(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.events))
+        _aws_cdk_aws_codecommit_RepositoryEventTrigger(p.events);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions(p) {
     if (p == null)
         return;
@@ -38,8 +38,6 @@ function _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions(p) {
         _aws_cdk_aws_codecommit_RepositoryNotificationEvents(p.events);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_codecommit_Code(p) {
-}
 function _aws_cdk_aws_codecommit_CfnRepositoryProps(p) {
     if (p == null)
         return;
@@ -50,6 +48,8 @@ function _aws_cdk_aws_codecommit_CfnRepositoryProps(p) {
         require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_codecommit_Code(p) {
+}
 function _aws_cdk_aws_codecommit_CfnRepository(p) {
 }
 function _aws_cdk_aws_codecommit_CfnRepository_S3Property(p) {
@@ -77,5 +77,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_codecommit_RepositoryEventTrigger, _aws_cdk_aws_codecommit_RepositoryNotificationEvents, _aws_cdk_aws_codecommit_ReferenceEvent, _aws_cdk_aws_codecommit_OnCommitOptions, _aws_cdk_aws_codecommit_CodeConfig, _aws_cdk_aws_codecommit_RepositoryTriggerOptions, _aws_cdk_aws_codecommit_RepositoryProps, _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions, _aws_cdk_aws_codecommit_Code, _aws_cdk_aws_codecommit_CfnRepositoryProps, _aws_cdk_aws_codecommit_CfnRepository, _aws_cdk_aws_codecommit_CfnRepository_S3Property, _aws_cdk_aws_codecommit_CfnRepository_RepositoryTriggerProperty, _aws_cdk_aws_codecommit_CfnRepository_CodeProperty, _aws_cdk_aws_codecommit_IRepository, _aws_cdk_aws_codecommit_Repository };
+module.exports = { print, _aws_cdk_aws_codecommit_RepositoryEventTrigger, _aws_cdk_aws_codecommit_RepositoryNotificationEvents, _aws_cdk_aws_codecommit_ReferenceEvent, _aws_cdk_aws_codecommit_OnCommitOptions, _aws_cdk_aws_codecommit_CodeConfig, _aws_cdk_aws_codecommit_RepositoryProps, _aws_cdk_aws_codecommit_RepositoryTriggerOptions, _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions, _aws_cdk_aws_codecommit_CfnRepositoryProps, _aws_cdk_aws_codecommit_Code, _aws_cdk_aws_codecommit_CfnRepository, _aws_cdk_aws_codecommit_CfnRepository_S3Property, _aws_cdk_aws_codecommit_CfnRepository_RepositoryTriggerProperty, _aws_cdk_aws_codecommit_CfnRepository_CodeProperty, _aws_cdk_aws_codecommit_IRepository, _aws_cdk_aws_codecommit_Repository };
 module.exports.DeprecationError = DeprecationError;
